@@ -14,10 +14,12 @@
  * limitations under the License.
  */
 
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file gssapi/source/library/globus_gsi_gss_error.c
+ * @file globus_gsi_gss_error.c
  * @author Sam Lang, Sam Meder
  */
+#endif
 
 #include "globus_i_gsi_gss_utils.h"
 #include "globus_gsi_gss_constants.h"
