@@ -21,10 +21,6 @@
 /**
  * @file globus_i_gsi_gss_utils.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: globus_i_gsi_gss_utils.h,v $
- * $Revision: 1.24.2.1 $
- * $Date: 2012/02/13 14:44:54 $
  */
 #endif
 
@@ -239,7 +235,6 @@ globus_i_gsi_gss_create_anonymous_cred(
     gss_cred_id_t *                     output_cred_handle,
     const gss_cred_usage_t              cred_usage);
 
-#if LINK_WITH_INTERNAL_OPENSSL_API
 OM_uint32
 globus_i_gsi_gss_cred_read_bio(
     OM_uint32 *                         minor_status,
@@ -253,7 +248,6 @@ globus_i_gsi_gss_cred_read(
     const gss_cred_usage_t              cred_usage,
     gss_cred_id_t *                     cred_handle,
     const X509_NAME *                   desired_subject);
-#endif /* LINK_WITH_INTERNAL_OPENSSL_API */
 
 OM_uint32
 globus_i_gsi_gss_create_cred(
@@ -291,6 +285,7 @@ globus_i_gsi_gss_retrieve_peer(
     gss_ctx_id_desc *                   context_handle,
     const gss_cred_usage_t              cred_usage);
 
+#if LINK_WITH_INTERNAL_OPENSSL_API
 OM_uint32
 globus_i_gsi_gss_SSL_write_bio(
     OM_uint32 *                         minor_status,
@@ -302,6 +297,7 @@ globus_i_gsi_gss_SSL_read_bio(
     OM_uint32 *                         minor_status,
     gss_ctx_id_desc *                   context,
     BIO *                               bp);
+#endif
 
 OM_uint32
 globus_i_gsi_gss_get_context_goodtill(
@@ -345,7 +341,7 @@ globus_i_gsi_gssapi_error_chain_result(
 
 globus_result_t
 globus_i_gsi_gssapi_error_join_chains_result(
-    globus_result_t                     outter_error,
+    globus_result_t                     outer_error,
     globus_result_t                     inner_error);
 
 OM_uint32
